# -*- coding: utf-8 -*-
#
# «irexec Handler» - For program execution from button pressing
#
# Copyright (C) 2010, John Baab, for Mythbuntu
# Copyright (C) 2008, Mario Limonciello, for Mythbuntu
#
#
# Mythbuntu is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3 of the License, or at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this application; if not, write to the Free Software Foundation, Inc., 51
# Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
##################################################################################

from MythbuntuLircGenerator.core import ProgramHandler

class IRExecHandler(ProgramHandler):
    def __init__(self,lircd, lircrc,repeat,delay):
        application_name="irexec"
        application_dictionary={ \
            "power,clear":"(kill $(pgrep mythfrontend) || true) && mythfrontend --service &", \
        }
        ProgramHandler.__init__(self,application_name,application_dictionary,lircd,lircrc,repeat,delay)


